# Continuum using JavaScript, Jasmine, Karma, and Chrome

This is a sample Continuum 6.4.0 project that tests arbitrary HTML for accessibility concerns using JavaScript, specifically Jasmine and Karma using Google Chrome.

Both the arbitrary HTML that's tested for accessibility and the Jasmine tests for that arbitrary HTML are defined in the `Shell/spec/a11y.js` file.

## Prerequisites
* Node
* Google Chrome

## Installation
1. Install dependencies:

        npm install

## Usage
### Linux / MacOS
1. Run accessibility tests:

        npm run test

### Windows
1. Run accessibility tests:

        npm run test:win

## Integrating With Level Access Platform

### Configuration
In order to integrate with the Level Access Platform you will need to set some properties in the `continuum.conf.js` file located in the `Shell/js` directory.

    "levelAccessPlatform": {
      "orgInstanceUrl": "https://org.instance.domain/",
      "apiKey": "",
      "workspaceId": "",
      "digitalPropertyId": "",
      "scanTagId": ""
    },

#### Properties
* levelAccessPlatform - This property is used to group all of the configuration properties related to integrating with the Level Access Platform.
* orgInstanceUrl - This is the base organization URL where the Level Access Platform services are located. This property is required and will be used for all scan sessions.
* apiKey - This is the API key used in requests to the Level Access Platform services. This property is required and will be used for all scan sessions.
* workspaceId - This is the id or the workspace used when opening a scan session in the Level Access Platform. This property is optional and can either be set here to apply to all scan sessions or provided / overridden programatically when opening a new scan session.
* digitalPropertyId - This is the id or the digital property used when opening a scan session in the Level Access Platform. This property is optional and can either be set here to apply to all scan sessions or provided / overridden programatically when opening a new scan session.
* scanTagId - This is the id or the scan tag used when opening a scan session in the Level Access Platform. This property is optional and can either be set here to apply to all scan sessions or provided / overridden programatically when opening a new scan session.

### Test For Assertions
The Level Access Platform accepts test results in the form of assertions. In order for Continuum to produce test results in this format you will need to call the `runAllTestsForAssertions()` method. This will return an array of `Assertion` objects.

### Get The Reporting Service
Submitting results to the Level Access Platform is done through a reporting service. You will need to retrieve an instance of the `LevelAccessPlatformReportingService` from Continuum by accessing the `LevelAccessPlatformReportingService` property. The returned reporting service instance will allow you to open and complete scan sessions and submit test results.

### Open A Scan Session
Before you can submit any test results to the Level Access Platform you will need to have an active scan session. You can open a new scan session by calling the `openScanSession()` method on the `LevelAccessPlatformReportingService` instance retrieved from Continuum. A name will need to be provided for your scan session.

### Submit Results
Once you have opened a scan session you will be able to submit test results to the Level Access Platform. This can be done by calling the `submit()` method on the `LevelAccessPlatformReportingService` instance retrieved from Continuum passing an array of `Assertion` objects. The supplied assertions will be ent to the Level Access Platform and stored as findings for the URL the browser is currently at. The page title and screen dimensions will also be automatically recorded and sent along with the assertions.

### Complete The Scan Session
When you have finished testing you can complete your scan session by calling the `completeScanSession()` method on the `LevelAccessPlatformReportingService` instance retrieved from Continuum.

### Example
Update your `Shell/spec/a11y.js` file to include the following:

        describe('my component', () => {
                it('should be accessible', async () => {
                        document.head.innerHTML = "";
                        document.body.innerHTML = '<div id="target"><img src="#"></div>';

                        const assertions = await continuum.runAllTestsForAssertions();

                        const failedAssertions = assertions.filter((assertion) => {
                                return assertion.outcome === 'fail';
                        });

                        try {
                                expect(failedAssertions.length).toBe(0);
                        } finally {
                                console.log();
                                console.log(`${failedAssertions.length} of ${assertions.length} assertions failed:`);
                                console.log(JSON.stringify(failedAssertions, null, 2));

                                await submitAssertionsToLevelAccessPlatform(assertions);
                        }
                });
        });

        async function submitAssertionsToLevelAccessPlatform(assertions) {
                const levelAccessPlatformReportingService = continuum.LevelAccessPlatformReportingService;

                console.log("Submitting accessibility concerns to Level Access Platform...");
                await levelAccessPlatformReportingService.openScanSession({
                        sessionName: 'Sample Scan'
                });
                try {
                        await levelAccessPlatformReportingService.submit(assertions);
                } finally {
                        await levelAccessPlatformReportingService.completeScanSession();
                }
                console.log(`Assertions submitted to Level Access Platform`);
        }

## Support
Rich API documentation for all the functionality supported out of the box with our Continuum JavaScript SDK, which this sample project uses, can be found [here](https://tools.levelaccess.net/continuum/docs/latest/jsdoc/index.html).

Questions can be emailed to Level Access support at support@levelaccess.com.
