beforeAll(async () => {
	jasmine.DEFAULT_TIMEOUT_INTERVAL = 100000;

	// initialize Continuum
	await continuum.setUp(null, null, window);
});

describe('my component', () => {
	it('should be accessible', async () => {
		// render component
		document.head.innerHTML = "";
		document.body.innerHTML = '<div id="target"><img src="#"></div>';

		// select component
		const targetNode = document.querySelector("#target");

		// test component and its children for accessibility
		// (you could also simply pass in "#target" as a parameter to runAllTestsOnNode instead)
		const accessibilityConcerns = await continuum.runAllTestsOnNode(targetNode);

		try {
			expect(accessibilityConcerns.length).toBe(0);
		} finally {
			console.log();
			console.log(`${accessibilityConcerns.length} accessibility concern(s) found:`);
			console.log(JSON.stringify(accessibilityConcerns, null, 2));

			// to send these accessibility concerns from Continuum to AMP, uncomment the line below and
			// edit the submitAccessibilityConcernsToAMP function according to our 'Sending Continuum Testing Results to AMP' support article:
			// https://support.levelaccess.com/hc/en-us/articles/360024510632-Sending-Continuum-Testing-Results-to-AMP
			//await submitAccessibilityConcernsToAMP(accessibilityConcerns);
		}
	});
});

async function submitAccessibilityConcernsToAMP(accessibilityConcerns) {
	console.log();
	console.log("Submitting accessibility concerns to AMP...");

	const ampReportingService = continuum.AMPReportingService;

	await ampReportingService.setActiveOrganization(12345);  // ID of AMP organization to submit test results to
	await ampReportingService.setActiveAsset(54321);  // ID of AMP asset to submit test results to
	await ampReportingService.setActiveReportByName("Example Report");
	await ampReportingService.setActiveModuleByName("Example Module", "Example Component");
	await ampReportingService.setActiveReportManagementStrategy(ReportManagementStrategy.OVERWRITE);
	await ampReportingService.setActiveModuleManagementStrategy(ModuleManagementStrategy.OVERWRITE);
	await ampReportingService.submitAccessibilityConcernsToAMP(accessibilityConcerns);

	console.log(`Accessibility concerns submitted to AMP: ${ampReportingService.activeModule.getAMPUrl()}`);
	console.log();
}

